@@ -1,23 +1,25 @@
 #' Plot the cluster tree
-#' 
+#'
 #' Plot the structure of a \code{\linkS4class{ClusterTree}} object
 #'
 #' @details Plot the structure of \code{clustertree} object, with the nodes labeled by corresponding
 #' elimination node. The circles represent continuous clusters, while the boxes represent discrete clusters.
-#'
+#' This function requires \code{Rgraphviz} package.
 #' @param tree a \code{\linkS4class{ClusterTree}} object
 #' @param color nodes color
-#' 
+#'
 #' @author Han Yu
-#' @examples 
+#' @examples
+#'
+#' \dontrun{
+#' library("Rgraphviz")
 #' data(toytree)
 #' PlotTree(toytree)
-#' 
-#' @references Cowell, R. G. (2005). Local propagation in conditional Gaussian Bayesian networks. 
-#' Journal of Machine Learning Research, 6(Sep), 1517-1550.  
-#' 
-#' @importFrom Rgraphviz plot
-#' 
+#' }
+#'
+#' @references Cowell, R. G. (2005). Local propagation in conditional Gaussian Bayesian networks.
+#' Journal of Machine Learning Research, 6(Sep), 1517-1550.
+#'
 #' @export
 
 PlotTree <- function(tree, color="gray90") {
@@ -39,7 +41,8 @@ PlotTree <- function(tree, color="gray90") {
   fill.color <- rep(color, length(cs.names))
   names(fill.color) <- cs.names
   nAttrs$fillcolor <- fill.color
-  Rgraphviz::plot(tree.graph, nodeAttrs=nAttrs, main="")
-  
+  # Rgraphviz::plot(tree.graph, nodeAttrs=nAttrs, main="")
+  graph_plot <- Rgraphviz::layoutGraph(tree.graph, nodeAttrs=nAttrs)
+  Rgraphviz::renderGraph(graph_plot)
 }
 
